@@ -34,7 +34,7 @@ from twisted.internet.defer import inlineCallbacks
 
 from autobahn.wamp import protocol
 from autobahn.wamp.types import ComponentConfig
-from autobahn.websocket.protocol import parseWsUrl
+from autobahn.websocket.util import parse_url
 from autobahn.twisted.websocket import WampWebSocketClientFactory
 
 # new API
@@ -91,9 +91,7 @@ class ApplicationRunner(object):
 
     log = txaio.make_logger()
 
-    def __init__(self, url, realm, extra=None, serializers=None,
-                 debug=False, debug_app=False,
-                 ssl=None, proxy=None):
+    def __init__(self, url, realm, extra=None, serializers=None, ssl=None, proxy=None):
         """
 
         :param url: The WebSocket URL of the WAMP router to connect to (e.g. `ws://somehost.com:8090/somepath`)
@@ -109,12 +107,6 @@ class ApplicationRunner(object):
            Serializers must implement :class:`autobahn.wamp.interfaces.ISerializer`.
         :type serializers: list
 
-        :param debug: Turn on low-level debugging.
-        :type debug: bool
-
-        :param debug_app: Turn on app-level debugging.
-        :type debug_app: bool
-
         :param ssl: (Optional). If specified this should be an
             instance suitable to pass as ``sslContextFactory`` to
             :class:`twisted.internet.endpoints.SSL4ClientEndpoint`` such
@@ -135,8 +127,6 @@ class ApplicationRunner(object):
         self.realm = realm
         self.extra = extra or dict()
         self.serializers = serializers
-        self.debug = debug
-        self.debug_app = debug_app
         self.ssl = ssl
         self.proxy = proxy
 
@@ -167,13 +157,9 @@ class ApplicationRunner(object):
             from twisted.internet import reactor
             txaio.use_twisted()
             txaio.config.loop = reactor
+            txaio.start_logging(level='info')
 
-            if self.debug or self.debug_app:
-                txaio.start_logging(level='debug')
-            else:
-                txaio.start_logging(level='info')
-
-        isSecure, host, port, resource, path, params = parseWsUrl(self.url)
+        isSecure, host, port, resource, path, params = parse_url(self.url)
 
         # factory for use ApplicationSession
         def create():
@@ -190,12 +176,10 @@ class ApplicationRunner(object):
                     # caller to deal with errors
                     raise
             else:
-                session.debug_app = self.debug_app
                 return session
 
         # create a WAMP-over-WebSocket transport client factory
-        transport_factory = WampWebSocketClientFactory(create, url=self.url, serializers=self.serializers,
-                                                       proxy=self.proxy, debug=self.debug)
+        transport_factory = WampWebSocketClientFactory(create, url=self.url, serializers=self.serializers, proxy=self.proxy)
 
         # supress pointless log noise like
         # "Starting factory <autobahn.twisted.websocket.WampWebSocketClientFactory object at 0x2b737b480e10>""
@@ -375,9 +359,7 @@ class Application(object):
         self.session = _ApplicationSession(config, self)
         return self.session
 
-    def run(self, url=u"ws://localhost:8080/ws", realm=u"realm1",
-            debug=False, debug_app=False,
-            start_reactor=True):
+    def run(self, url=u"ws://localhost:8080/ws", realm=u"realm1", start_reactor=True):
         """
         Run the application.
 
@@ -385,14 +367,9 @@ class Application(object):
         :type url: unicode
         :param realm: The realm on the WAMP router to join.
         :type realm: unicode
-        :param debug: Turn on low-level debugging.
-        :type debug: bool
-        :param debug_app: Turn on app-level debugging.
-        :type debug_app: bool
         """
-        runner = ApplicationRunner(url, realm,
-                                   debug=debug, debug_app=debug_app)
-        runner.run(self.__call__, start_reactor)
+        runner = ApplicationRunner(url, realm)
+        return runner.run(self.__call__, start_reactor)
 
     def register(self, uri=None):
         """
@@ -562,8 +539,7 @@ if service:
         """
         factory = WampWebSocketClientFactory
 
-        def __init__(self, url, realm, make, extra=None, context_factory=None,
-                     debug=False, debug_app=False):
+        def __init__(self, url, realm, make, extra=None, context_factory=None):
             """
 
             :param url: The WebSocket URL of the WAMP router to connect to (e.g. `ws://somehost.com:8090/somepath`)
@@ -583,20 +559,12 @@ if service:
                 the ``listenSSL()`` call; see https://twistedmatrix.com/documents/current/api/twisted.internet.interfaces.IReactorSSL.connectSSL.html
             :type context_factory: twisted.internet.ssl.ClientContextFactory or None
 
-            :param debug: Turn on low-level debugging.
-            :type debug: bool
-
-            :param debug_app: Turn on app-level debugging.
-            :type debug_app: bool
-
             You can replace the attribute factory in order to change connectionLost or connectionFailed behaviour.
             The factory attribute must return a WampWebSocketClientFactory object
             """
             self.url = url
             self.realm = realm
             self.extra = extra or dict()
-            self.debug = debug
-            self.debug_app = debug_app
             self.make = make
             self.context_factory = context_factory
             service.MultiService.__init__(self)
@@ -606,17 +574,16 @@ if service:
             """
             Setup the application component.
             """
-            is_secure, host, port, resource, path, params = parseWsUrl(self.url)
+            is_secure, host, port, resource, path, params = parse_url(self.url)
 
             # factory for use ApplicationSession
             def create():
                 cfg = ComponentConfig(self.realm, self.extra)
                 session = self.make(cfg)
-                session.debug_app = self.debug_app
                 return session
 
             # create a WAMP-over-WebSocket transport client factory
-            transport_factory = self.factory(create, url=self.url, debug=self.debug)
+            transport_factory = self.factory(create, url=self.url)
 
             # setup the client from a Twisted endpoint
 
